@@ -1,6 +1,6 @@
 package Supervisord::Client;
 {
-  $Supervisord::Client::VERSION = '0.1_02';
+  $Supervisord::Client::VERSION = '0.2';
 }
 use strict;
 use warnings;
@@ -21,15 +21,13 @@ has path_to_supervisor_config => (
 );
 
 has serverurl => (
-    is       => 'ro',
-    required => 0,
+    is       => 'lazy',
 );
 
 has rpc => (
     is      => 'lazy',
     handles => { ua => 'useragent' },
 );
-has _serverurl => ( is => 'lazy' );
 
 has username => (
     is => 'ro',
@@ -42,9 +40,8 @@ has password => (
 );
 
 
-sub _build__serverurl {
+sub _build_serverurl {
     my $self = shift;
-    return $self->serverurl if $self->serverurl;
     my $hash =
       Config::INI::Reader->read_file( $self->path_to_supervisor_config );
     return $hash->{supervisorctl}{serverurl}
@@ -54,7 +51,7 @@ sub _build__serverurl {
 
 sub _build_rpc {
     my $self = shift;
-    my $url  = $self->_serverurl;
+    my $url  = $self->serverurl;
     my $uri = URI->new( $url );
     if( lc($uri->scheme) eq 'unix' ) {
         my $socket_uri = URI->new("supervisorsocketunix:");
@@ -127,7 +124,7 @@ Constructor, provided by Moo.
 
 Access to the RPC::XML::Client object.
 
-=item ua
+=head2 ua
 
 Access to the LWP::UserAgent object from the RPC::XML::Client
 
